@@ -2,20 +2,20 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: PMCMR.Rnw:88-90
+### code chunk number 1: PMCMR.Rnw:90-92
 ###################################################
 library("graphics")
 boxplot(count ~ spray, data=InsectSprays)
 
 
 ###################################################
-### code chunk number 2: PMCMR.Rnw:98-99
+### code chunk number 2: PMCMR.Rnw:100-101
 ###################################################
 kruskal.test(count ~ spray, data=InsectSprays)
 
 
 ###################################################
-### code chunk number 3: PMCMR.Rnw:104-108
+### code chunk number 3: PMCMR.Rnw:106-110
 ###################################################
 require(PMCMR)
 data(InsectSprays)
@@ -24,25 +24,59 @@ posthoc.kruskal.nemenyi.test(x=count, g=spray, dist="Tukey")
 
 
 ###################################################
-### code chunk number 4: PMCMR.Rnw:112-113
+### code chunk number 4: PMCMR.Rnw:114-115
 ###################################################
 posthoc.kruskal.nemenyi.test(count ~ spray, data=InsectSprays, dist="Tukey")
 
 
 ###################################################
-### code chunk number 5: PMCMR.Rnw:118-119
+### code chunk number 5: PMCMR.Rnw:120-121
 ###################################################
 (out <- posthoc.kruskal.nemenyi.test(x=count, g=spray, dist="Chisquare"))
 
 
 ###################################################
-### code chunk number 6: PMCMR.Rnw:124-125
+### code chunk number 6: PMCMR.Rnw:126-127
 ###################################################
 print(out$statistic)
 
 
 ###################################################
-### code chunk number 7: PMCMR.Rnw:178-187
+### code chunk number 7: PMCMR.Rnw:169-173
+###################################################
+require(PMCMR)
+data(InsectSprays)
+attach(InsectSprays)
+posthoc.kruskal.dunn.test(x=count, g=spray, p.adjust.method="none")
+
+
+###################################################
+### code chunk number 8: PMCMR.Rnw:178-182
+###################################################
+require(PMCMR)
+data(InsectSprays)
+attach(InsectSprays)
+posthoc.kruskal.dunn.test(x=count, g=spray, p.adjust.method="bonferroni")
+
+
+###################################################
+### code chunk number 9: PMCMR.Rnw:202-207
+###################################################
+require(stats) 
+data(PlantGrowth)
+attach(PlantGrowth)
+kruskal.test(weight, group)
+dunn.test.control(weight,group, "bonferroni")
+
+
+###################################################
+### code chunk number 10: PMCMR.Rnw:213-214
+###################################################
+summary.lm(aov(weight ~ group))
+
+
+###################################################
+### code chunk number 11: PMCMR.Rnw:251-260
 ###################################################
 require(PMCMR)
 y <- matrix(c(
@@ -56,7 +90,7 @@ print(y)
 
 
 ###################################################
-### code chunk number 8: PMCMR.Rnw:194-197
+### code chunk number 12: PMCMR.Rnw:267-270
 ###################################################
 library("graphics")
 groups <- gl(6,6,labels=colnames(y))
@@ -64,13 +98,13 @@ boxplot(as.vector(y) ~ groups)
 
 
 ###################################################
-### code chunk number 9: PMCMR.Rnw:204-205
+### code chunk number 13: PMCMR.Rnw:277-278
 ###################################################
 friedman.test(y)
 
 
 ###################################################
-### code chunk number 10: PMCMR.Rnw:210-211
+### code chunk number 14: PMCMR.Rnw:283-284
 ###################################################
 posthoc.friedman.nemenyi.test(y)
 
